@@ -702,10 +702,16 @@ public class UnixCrypt {
       int numSaltChars = saltChars.length;
       String salt;
       
-      salt = (new StringBuffer()).append(saltChars[Math.abs(randomGenerator.nextInt()) % numSaltChars]).append(saltChars[Math.abs(randomGenerator.nextInt()) % numSaltChars]).toString();
+      salt = (new StringBuffer()).append(saltChars[randomUnsigned() % numSaltChars]).append(saltChars[randomUnsigned() % numSaltChars]).toString();
       
       return crypt(salt, original);
     }
+
+    private static final java.util.Random randomGenerator = new java.util.Random();
+    private static int randomUnsigned() {
+        // int randomNumber = random.nextInt(max - min) + min;
+        return randomGenerator.nextInt(Integer.MAX_VALUE);
+    }
     
     /**
      * <P>Check that <I>enteredPassword</I> encrypts to
